pub struct DiagnosticsLogging {
options: [bool; 11],
}Expand description
The current configuration of the diagnostic options for Servo.
Fields
options: [bool; 11]Implementations
Sourceimpl DiagnosticsLogging
impl DiagnosticsLogging
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DiagnosticsLogging configuration.
In builds with debug assertions enabled, this will automatically read and parse the SERVO_DIAGNOSTICS environment variable if it is set.
Sourcepub fn toggle_option(&mut self, option: DiagnosticsLoggingOption, enabled: bool)
pub fn toggle_option(&mut self, option: DiagnosticsLoggingOption, enabled: bool)
Enables or disables the diagnostics represented by the given DiagnosticsLoggingOption
variant.
Sourcepub fn is_enabled(&self, option: DiagnosticsLoggingOption) -> bool
pub fn is_enabled(&self, option: DiagnosticsLoggingOption) -> bool
Returns true if the given diagnostic option is enabled.