pub struct Opts {Show 17 fields
pub time_profiling: Option<OutputOptions>,
pub time_profiler_trace_path: Option<String>,
pub hard_fail: bool,
pub debug: DiagnosticsLogging,
pub multiprocess: bool,
pub force_ipc: bool,
pub background_hang_monitor: bool,
pub sandbox: bool,
pub random_pipeline_closure_probability: Option<f32>,
pub random_pipeline_closure_seed: Option<usize>,
pub shaders_path: Option<PathBuf>,
pub config_dir: Option<PathBuf>,
pub certificate_path: Option<String>,
pub ignore_certificate_errors: bool,
pub unminify_js: bool,
pub local_script_source: Option<String>,
pub unminify_css: bool,
}Expand description
Global flags for Servo, currently set on the command line.
Fields
time_profiling: Option<OutputOptions>None to disable the time profiler or Some to enable it with:
- an interval in seconds to cause it to produce output on that interval.
(
i.e. -p 5). - a file path to write profiling info to a TSV file upon Servo’s termination.
(
i.e. -p out.tsv).
time_profiler_trace_path: Option<String>When the profiler is enabled, this is an optional path to dump a self-contained HTML file visualizing the traces as a timeline.
hard_fail: boolTrue to exit on thread failure instead of displaying about:failure.
debug: DiagnosticsLoggingDebug options that are used by developers to control Servo behavior for debugging purposes.
multiprocess: boolWhether we’re running in multiprocess mode.
force_ipc: boolWhether to force using ipc_channel instead of crossbeam_channel in singleprocess mode. Does nothing in multiprocess mode.
background_hang_monitor: boolWhether we want background hang monitor enabled or not
sandbox: boolWhether we’re running inside the sandbox.
random_pipeline_closure_probability: Option<f32>Probability of randomly closing a pipeline, used for testing the hardening of the constellation.
random_pipeline_closure_seed: Option<usize>The seed for the RNG used to randomly close pipelines, used for testing the hardening of the constellation.
shaders_path: Option<PathBuf>Load shaders from disk.
config_dir: Option<PathBuf>Directory for a default config directory
certificate_path: Option<String>Path to PEM encoded SSL CA certificate store.
ignore_certificate_errors: boolWhether or not to completely ignore SSL certificate validation errors. TODO: We should see if we can eliminate the need for this by fixing https://github.com/servo/servo/issues/30080.
unminify_js: boolUnminify Javascript.
local_script_source: Option<String>Directory path that was created with “unminify-js”
unminify_css: boolUnminify Css.