DiagnosticsLoggingOption

Enum DiagnosticsLoggingOption 

#[repr(i32)]
pub enum DiagnosticsLoggingOption { StyleTree = 0, RuleTree = 1, FlowTree = 2, StackingContextTree = 3, ScrollTree = 4, DisplayList = 5, RelayoutEvent = 6, ProfileScriptEvents = 7, StyleStatistics = 8, GcProfile = 9, ProgressiveWebMetrics = 10, AccessibilityTree = 11, }
The set of diagnostic options that can be enabled in Servo.

Variants



StyleTree = 0

Log the DOM after each restyle



RuleTree = 1

Log the rule tree



FlowTree = 2

Log the fragment tree after each layout



StackingContextTree = 3

Log the stacking context tree after each layout



ScrollTree = 4

Log the scroll tree (the hierarchy of scrollable areas) after each layout



DisplayList = 5

Log the display list after each layout



RelayoutEvent = 6

Log notifications when a relayout occurs



ProfileScriptEvents = 7

Periodically log on which events script threads spend their processing time



StyleStatistics = 8

Log the the hit/miss statistics for the style sharing cache after each restyle



GcProfile = 9

Log garbage collection passes and their durations



ProgressiveWebMetrics = 10

Log Progressive Web Metrics



AccessibilityTree = 11

Log the accessibility tree

Implementations

Source

impl DiagnosticsLoggingOption

pub fn help_option(&self) -> &str

Returns a string representation of this variant that is compatible with FromStr::from_str and DiagnosticsLogging::extend_from_string. This value can be used as a command-line argument for an application.

pub fn help_message(&self) -> &str

Returns a string with a short description of the diagnostic option. This value can be used as a command-line argument description for an application.

pub fn iter() -> impl Iterator<Item = Self>

Returns an Iterator that can be used to iterate over all the diagnostic options supported by Servo. This is useful when constructing a help message that enumerates all possible diagnostic flags and their respective help messages.