DiagnosticsLoggingOption

Enum DiagnosticsLoggingOption 

pub enum DiagnosticsLoggingOption {
    StyleTree,
    RuleTree,
    FlowTree,
    StackingContextTree,
    ScrollTree,
    DisplayList,
    RelayoutEvent,
    ProfileScriptEvents,
    StyleStatistics,
    GcProfile,
    ProgressiveWebMetrics,
}
The set of diagnostic options that can be enabled in Servo.

Variants



StyleTree

Log the DOM after each restyle



RuleTree

Log the rule tree



FlowTree

Log the fragment tree after each layout



StackingContextTree

Log the stacking context tree after each layout



ScrollTree

Log the scroll tree (the hierarchy of scrollable areas) after each layout



DisplayList

Log the display list after each layout



RelayoutEvent

Log notifications when a relayout occurs



ProfileScriptEvents

Periodically log on which events script threads spend their processing time



StyleStatistics

Log the the hit/miss statistics for the style sharing cache after each restyle



GcProfile

Log garbage collection passes and their durations



ProgressiveWebMetrics

Log Progressive Web Metrics

Implementations

Source

impl DiagnosticsLoggingOption

pub fn help_option(&self) -> &str

Returns a string representation of this variant that is compatible with FromStr::from_str and DiagnosticsLogging::extend_from_string. This value can be used as a command-line argument for an application.

pub fn help_message(&self) -> &str

Returns a string with a short description of the diagnostic option. This value can be used as a command-line argument description for an application.

pub fn iter() -> impl Iterator<Item = Self>

Returns an Iterator that can be used to iterate over all the diagnostic options supported by Servo. This is useful when constructing a help message that enumerates all possible diagnostic flags and their respective help messages.