pub struct DiagnosticsLogging {
pub help: bool,
pub style_tree: bool,
pub rule_tree: bool,
pub flow_tree: bool,
pub stacking_context_tree: bool,
pub scroll_tree: bool,
pub display_list: bool,
pub relayout_event: bool,
pub profile_script_events: bool,
pub style_statistics: bool,
pub gc_profile: bool,
pub progressive_web_metrics: bool,
}Expand description
Debug options for Servo, currently set on the command line with -Z
Fields
help: boolList all the debug options.
style_tree: boolPrint the DOM after each restyle.
rule_tree: boolLog the rule tree.
flow_tree: boolLog the fragment tree after each layout.
stacking_context_tree: boolLog the stacking context tree after each layout.
scroll_tree: boolLog the scroll tree after each layout.
Displays the hierarchy of scrollable areas and their properties.
display_list: boolLog the display list after each layout.
relayout_event: boolLog notifications when a relayout occurs.
profile_script_events: boolPeriodically log on which events script threads spend their processing time.
style_statistics: boolLog style sharing cache statistics to after each restyle.
Shows hit/miss statistics for the style sharing cache
gc_profile: boolLog garbage collection passes and their durations.
progressive_web_metrics: boolLog Progressive Web Metrics.
Implementations
Sourceimpl DiagnosticsLogging
impl DiagnosticsLogging
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DiagnosticsLogging configuration.
In non-production builds, this will automatically read and parse the SERVO_DIAGNOSTICS environment variable if it is set.
Sourcefn print_debug_options_usage(app: &str)
fn print_debug_options_usage(app: &str)
Print available diagnostic logging options and their descriptions.